<?php

$base_url = sprintf("http://%s/archive", $HTTP_SERVER_VARS['HTTP_HOST']);
$authenticated = (bool)get_cfg_var('imap_use_gss');

if($authenticated) {
  putenv("KRB5CCNAME=".$_SERVER["KRB5CCNAME"]);
  $server = "{cyrus.andrew.cmu.edu:143/user=" . $_SERVER["REMOTE_USER"] . "}";
} else {
  $server = "{cyrus.andrew.cmu.edu:143/anonymous}";
}

$bboards = array("archive.info-cyrus", "archive.cyrus-sasl", "archive.cyrus-devel", "archive.imap", "archive.c-client", "org.acs.asg.project.mail.commits", "org.acs.asg.project.sasl.commits");

function printheader($mbox, $box, $msgnum, $subtitle) {
if($msgnum >= 0) {
   $msgnumstr = " - ".imap_msgno($mbox,$msgnum);
} else {
   $msgnumstr = "";
}

echo "
<HTML>
<HEAD>
<TITLE>$box$msgnumstr</TITLE>
</HEAD>
<BODY BGCOLOR=WHITE>
<FONT SIZE=+4 FACE=Helvetica>$box$msgnumstr</FONT>$subtitle
<HR>";
}

function printbboardlist($current) {
global $bboards;

$first=true;

echo "<form action=\"mailbox.php\" method=\"get\" name=\"mboxSelect\">\n";
echo "<select name=\"mailbox\" onChange=\"document.mboxSelect.submit()\">\n";

foreach ($bboards as $bb) {
   if($first) {
	$first = false;
   }

   if(!strcmp($bb, $current)) {
	$selected = "SELECTED";
   } else {
	$selected = "";
   }

   echo "<option value=\"$bb\" $selected>$bb</option>\n";
}

echo "</select><input type=\"submit\" value=\"View\"></form>\n";

}

?>
